@@ -1,16 +1,16 @@
-use pilka_lib::*;
-
-#[cfg(debug_assertions)]
-#[allow(unused_imports)]
-#[allow(clippy::single_component_path_imports)]
-use pilka_dyn;
+#![feature(crate_visibility_modifier)]
 
 mod audio;
 mod default_shaders;
 mod input;
 mod recorder;
+mod renderer;
+mod util;
 
-use pilka::create_folder;
+use util::create_folder;
+
+use crate::renderer::PilkaRender;
+use pilka_ash::*;
 
 use ash::{vk, SHADER_ENTRY_POINT, SHADER_PATH};
 use eyre::*;
@@ -41,7 +41,7 @@ fn main() -> Result<(), Box<dyn Error>> {
     // Initialize error hook.
     color_eyre::install()?;
 
-    let mut audio_context = audio::AudioContext::new()?;
+    // let mut audio_context = audio::AudioContext::new()?;
 
     let mut input = input::Input::new();
     let mut pause = false;
@@ -82,11 +82,11 @@ fn main() -> Result<(), Box<dyn Error>> {
     println!("Device name: {}", pilka.get_device_name()?);
     println!("Device type: {:?}", pilka.get_device_type());
     println!("Vulkan version: {}", pilka.get_vulkan_version_name()?);
-    println!("Audio host: {:?}", audio_context.host_id);
-    println!(
-        "Sample rate: {}, channels: {}",
-        audio_context.sample_rate, audio_context.num_channels
-    );
+    // println!("Audio host: {:?}", audio_context.host_id);
+    // println!(
+    //     "Sample rate: {}, channels: {}",
+    //     audio_context.sample_rate, audio_context.num_channels
+    // );
     println!("{}", ffmpeg_version);
     println!(
         "Default shader path:\n\t{}",
@@ -144,9 +144,9 @@ fn main() -> Result<(), Box<dyn Error>> {
                 input.process_position(&mut pilka.push_constant);
 
                 if !pause {
-                    let mut tmp_buf = [0f32; audio::FFT_SIZE];
-                    audio_context.get_fft(&mut tmp_buf);
-                    pilka.update_fft_texture(&tmp_buf).unwrap();
+                    // let mut tmp_buf = [0f32; audio::FFT_SIZE];
+                    // audio_context.get_fft(&mut tmp_buf);
+                    // pilka.update_fft_texture(&tmp_buf).unwrap();
 
                     dt = timeline.elapsed().saturating_sub(prev_time);
                     pilka.push_constant.time_delta = dt.as_secs_f32();
